@@ -7,32 +7,29 @@
 ;;;; Programmer:    Kevin M. Rosenberg
 ;;;; Date Started:  Feb 2002
 ;;;;
-;;;; $Id: objects.lisp 10373 2005-04-03 23:58:11Z kevin $
+;;;; $Id: objects.lisp 10608 2005-07-01 00:39:48Z kevin $
 ;;;;
-;;;; This file, part of UFFI, is Copyright (c) 2002 by Kevin M. Rosenberg
+;;;; This file, part of UFFI, is Copyright (c) 2002-2005 by Kevin M. Rosenberg
 ;;;;
-;;;; UFFI users are granted the rights to distribute and use this software
-;;;; as governed by the terms of the Lisp Lesser GNU Public License
-;;;; (http://opensource.franz.com/preamble.html), also known as the LLGPL.
 ;;;; *************************************************************************
 
 (in-package #:uffi)
 
-(defun size-of-foreign-type (type)
-  #+lispworks (fli:size-of type)
-  #+allegro (ff:sizeof-fobject type)
-  #+(or cmu scl)  (ash (eval `(alien:alien-size ,type)) -3) ;; convert from bits to bytes
-  #+sbcl  (ash (eval `(sb-alien:alien-size ,type)) -3) ;; convert from bits to bytes
-  #+clisp (values (ffi:size-of type))
-  #+(and mcl (not openmcl))
-  (let ((mcl-type (ccl:find-mactype type nil t)))
-    (if mcl-type 
-	(ccl::mactype-record-size mcl-type)
-      (ccl::record-descriptor-length (ccl:find-record-descriptor type t t)))) ;error if not a record
-  #+openmcl (ccl::%foreign-type-or-record-size type :bytes)
-  )
-
-
+(eval-when (:compile-toplevel :load-toplevel :execute)
+  (defun size-of-foreign-type (type)
+    #+lispworks (fli:size-of type)
+    #+allegro (ff:sizeof-fobject type)
+    #+(or cmu scl)  (ash (eval `(alien:alien-size ,type)) -3) ;; convert from bits to bytes
+    #+sbcl  (ash (eval `(sb-alien:alien-size ,type)) -3) ;; convert from bits to bytes
+    #+clisp (values (ffi:size-of type))
+    #+(and mcl (not openmcl))
+    (let ((mcl-type (ccl:find-mactype type nil t)))
+      (if mcl-type 
+	  (ccl::mactype-record-size mcl-type)
+	  (ccl::record-descriptor-length (ccl:find-record-descriptor type t t)))) ;error if not a record
+    #+openmcl (ccl::%foreign-type-or-record-size type :bytes)
+    ))
+  
 (defmacro allocate-foreign-object (type &optional (size :unspecified))
   "Allocates an instance of TYPE. If size is specified, then allocate
 an array of TYPE with size SIZE. The TYPE parameter is evaluated."
@@ -132,13 +129,14 @@ an array of TYPE with size SIZE. The TYPE parameter is evaluated."
   #+(or (and mcl (not openmcl))) obj
   #+(or allegro cmu sbcl scl openmcl) `(code-char ,obj)
   ;; lispworks varies whether deref'ing array vs. slot access of a char
-  #+lispworks
-  `(if (characterp ,obj) ,obj (code-char ,obj)))
+  #+lispworks `(if (characterp ,obj) ,obj (code-char ,obj)))
   
 (defmacro ensure-char-integer (obj)
   #+(or (and mcl (not openmcl))) `(char-code ,obj)
   #+(or allegro cmu sbcl scl openmcl) obj
-  `(if (characterp ,obj) (char-code ,obj) ,obj))
+  ;; lispworks varies whether deref'ing array vs. slot access of a char
+  #+lispworks
+  `(if (integerp ,obj) ,obj (char-code ,obj)))
 
 (defmacro ensure-char-storable (obj)
   #+(or lispworks (and mcl (not openmcl))) obj
